==> openshift-model-operator-6.8.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/EgressIPConfigFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EgressIPConfigFluent<A extends EgressIPConfigFluent<A>> extends BaseFluent<A>{
  public EgressIPConfigFluent() {
  }
  public EgressIPConfigFluent(EgressIPConfig instance) {
    instance = (instance != null ? instance : new EgressIPConfig());

    if (instance != null) {
      this.withReachabilityTotalTimeoutSeconds(instance.getReachabilityTotalTimeoutSeconds());
      this.withReachabilityTotalTimeoutSeconds(instance.getReachabilityTotalTimeoutSeconds());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Integer reachabilityTotalTimeoutSeconds;
  private Map<String,Object> additionalProperties;
  public Integer getReachabilityTotalTimeoutSeconds() {
    return this.reachabilityTotalTimeoutSeconds;
  }
  public A withReachabilityTotalTimeoutSeconds(Integer reachabilityTotalTimeoutSeconds) {
    this.reachabilityTotalTimeoutSeconds=reachabilityTotalTimeoutSeconds; return (A) this;
  }
  public boolean hasReachabilityTotalTimeoutSeconds() {
    return this.reachabilityTotalTimeoutSeconds != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EgressIPConfigFluent that = (EgressIPConfigFluent) o;
    if (!java.util.Objects.equals(reachabilityTotalTimeoutSeconds, that.reachabilityTotalTimeoutSeconds)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(reachabilityTotalTimeoutSeconds,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (reachabilityTotalTimeoutSeconds != null) { sb.append("reachabilityTotalTimeoutSeconds:"); sb.append(reachabilityTotalTimeoutSeconds + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-operator-6.9.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/EgressIPConfigFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class EgressIPConfigFluent<A extends EgressIPConfigFluent<A>> extends BaseFluent<A>{
  public EgressIPConfigFluent() {
  }
  
  public EgressIPConfigFluent(EgressIPConfig instance) {
    this.copyInstance(instance);
  }
  private Integer reachabilityTotalTimeoutSeconds;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(EgressIPConfig instance) {
    instance = (instance != null ? instance : new EgressIPConfig());
  
    if (instance != null) {
        this.withReachabilityTotalTimeoutSeconds(instance.getReachabilityTotalTimeoutSeconds());
        this.withReachabilityTotalTimeoutSeconds(instance.getReachabilityTotalTimeoutSeconds());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public Integer getReachabilityTotalTimeoutSeconds() {
    return this.reachabilityTotalTimeoutSeconds;
  }
  
  public A withReachabilityTotalTimeoutSeconds(Integer reachabilityTotalTimeoutSeconds) {
    this.reachabilityTotalTimeoutSeconds=reachabilityTotalTimeoutSeconds; return (A) this;
  }
  
  public boolean hasReachabilityTotalTimeoutSeconds() {
    return this.reachabilityTotalTimeoutSeconds != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EgressIPConfigFluent that = (EgressIPConfigFluent) o;
    if (!java.util.Objects.equals(reachabilityTotalTimeoutSeconds, that.reachabilityTotalTimeoutSeconds)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(reachabilityTotalTimeoutSeconds,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (reachabilityTotalTimeoutSeconds != null) { sb.append("reachabilityTotalTimeoutSeconds:"); sb.append(reachabilityTotalTimeoutSeconds + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
